{ pkgs, inputs, host, ... }:
let
  inherit (import ../../hosts/${host}/variables.nix) dockerEnable;
in
{
  programs = {
    hyprland.enable = true;
    seahorse.enable = true;
    adb.enable = true;
    gnupg.agent = {
      enable = true;
      enableSSHSupport = true;
    };
  };

  nixpkgs.config.allowUnfree = true;

  environment.systemPackages = with pkgs; [
    inputs.zen-browser.packages."${system}".beta # Firefox fork
    htop # CLI sysusage tool
    ffmpeg # Video / audio editing
    eza # LS replacement
    duf # Disk usage util
  ] ++ (if dockerEnable then [ docker-compose ] else []) ++ [
    brightnessctl # Brightness control
    gimp # Image editor
    hyprpicker # Color picker
    eog # Image viewer
    macchina # CLI sysinfo tool
    libnotify # Notifications
    lm_sensors # Hardware temps
    lshw # Detailed hardware information
    mpv # Video player
    nwg-displays # Monitor configs via GUI
    pciutils # Collection of tools for inspecting PCI devices
    ripgrep # grep++
    socat # Screenshot util
    unrar # .rar files
    unzip # .zip files
    wget # CLI fetch
    yazi # TUI file manager
    appimage-run # AppImage support
    kitty-themes # Themes for Kitty
    base16-schemes # Schemes for stylix
    vim # Text editor
    fuse # Virtual file systems
    greetd.tuigreet # Display Manager
    #(callPackage ../../packages/sddm-rose-pine.nix {}) # SDDM theme
    cloudflared # Cloudflare daemon
    sbctl # Secure Boot keys
  ] ++ [
    rustup # Rust toolchain manager
    clang # C compiler
    llvmPackages.bintools # LLVM
    (callPackage ../../packages/luau-lsp.nix { stdenv = pkgs.clangStdenv; }) # Luau-Lsp
    (callPackage ../../packages/luau.nix { stdenv = pkgs.clangStdenv; }) # Luau
  ];
}
